@@ -7,14 +7,14 @@
 import hashlib
 import os
 
-from jupyterlab_pygments import JupyterStyle  # type:ignore[import]
+from jupyterlab_pygments import JupyterStyle  # type:ignore[import-untyped]
 from pygments.style import Style
 from traitlets import Type, Unicode, Union
 
 from .base import Preprocessor
 
 try:
-    from notebook import DEFAULT_STATIC_FILES_PATH  # type:ignore[import]
+    from notebook import DEFAULT_STATIC_FILES_PATH  # type:ignore[import-not-found]
 except ImportError:
     DEFAULT_STATIC_FILES_PATH = None
 
