@@ -1,12 +1,14 @@
 """Module containing a preprocessor that executes the code cells
 and updates outputs"""
+from __future__ import annotations
+
 import typing as t
 
 from jupyter_client.manager import KernelManager
-from nbclient import NotebookClient
-from nbclient import execute as _execute
+from nbclient.client import NotebookClient
+from nbclient.client import execute as _execute
 
-# Backwards compatability for imported name
+# Backwards compatibility for imported name
 from nbclient.exceptions import CellExecutionError  # noqa
 
 # Copyright (c) IPython Development Team.
@@ -32,7 +34,7 @@ def executenb(*args, **kwargs):
 # We inherit from both classes to allow for traitlets to resolve as they did pre-6.0.
 # This unfortunately makes for some ugliness around initialization as NotebookClient
 # assumes it's a constructed class with a nb object that we have to hack around.
-class ExecutePreprocessor(Preprocessor, NotebookClient):
+class ExecutePreprocessor(Preprocessor, NotebookClient):  # type:ignore[misc]
     """
     Executes all the cells in a notebook
     """
@@ -50,8 +52,8 @@ class ExecutePreprocessor(Preprocessor, NotebookClient):
             self.resources = resources
 
     def preprocess(
-        self, nb: NotebookNode, resources: t.Any = None, km: t.Optional[KernelManager] = None
-    ) -> t.Tuple[NotebookNode, dict]:
+        self, nb: NotebookNode, resources: t.Any = None, km: KernelManager | None = None
+    ) -> tuple[NotebookNode, dict[str, t.Any]]:
         """
         Preprocess notebook executing each code cell.
 
