@@ -31,10 +31,7 @@ def indent(instr, nspaces=4, ntabs=0, flatten=False):
     if instr is None:
         return
     ind = "\t" * ntabs + " " * nspaces
-    if flatten:
-        pat = re.compile(r"^\s*", re.MULTILINE)
-    else:
-        pat = re.compile(r"^", re.MULTILINE)
+    pat = re.compile("^\\s*", re.MULTILINE) if flatten else re.compile("^", re.MULTILINE)
     outstr = re.sub(pat, ind, instr)
     if outstr.endswith(os.linesep + ind):
         return outstr[: -len(ind)]
