@@ -4,6 +4,7 @@ Contains writer base class.
 
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
+from __future__ import annotations
 
 from traitlets import List
 
@@ -14,7 +15,7 @@ class WriterBase(NbConvertBase):
     """Consumes output from nbconvert export...() methods and writes to a
     useful location."""
 
-    files = List(
+    files: List[str] = List(  # type:ignore[assignment]
         [],
         help="""
         List of the files that the notebook references.  Files will be
